/***************************************************************************
 *   Copyright (C) 2007-2009 by Glad Deschrijver                           *
 *   glad.deschrijver@gmail.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#ifndef QONJUGATOR_QONJUGATORLIB_H
#define QONJUGATOR_QONJUGATORLIB_H

#include <QObject>
#include <QStringList>
class QDir;
class QTranslator;

namespace Qonjugator
{

class Plugin;
class Verb;

/*!
 * This class contains the library for conjugating verbs in different languages.
 */

class QonjugatorController : public QObject
{
	Q_OBJECT
	Q_PROPERTY(QStringList pluginsDirList READ pluginsDirList WRITE setPluginsDirList)
	Q_PROPERTY(QString currentPlugin READ currentPlugin WRITE setCurrentPlugin)
	Q_PROPERTY(QStringList translationsDirList READ translationsDirList WRITE setTranslationsDirList)

public:
	QonjugatorController(QObject *parent = 0);
	~QonjugatorController();

	void setPluginsDirList(const QStringList &pluginsDirList);
	QStringList pluginsDirList() const;
	void loadPlugins();
	QStringList pluginsList() const;
	void setCurrentPlugin(const QString &pluginName);
	QString currentPlugin() const;

	void setTranslationsDirList(const QStringList &translationsDirList);
	QStringList translationsDirList() const;
	QTranslator *createTranslator(const QString &transBaseName, const QString &transDir) const;
	QTranslator *createTranslator(const QString &transBaseName) const;
	void loadPluginTranslations();

	void conjugate(const QString &verb);
	void setShowPronouns(bool show);
	bool showPronouns() const;
	QString description() const;
	QString inputInstructions() const;
	QString language() const;
	QStringList specialCharacters() const;
	QString infinitive() const;
	QString infinitiveBase() const;
	QString tenseMood(int tenseNum) const;
	QString tenseName(int tenseNum) const;
	QString subjectPronoun(int tenseNum, int timeNum) const;
	QString tense(int tenseNum, int timeNum) const;
	QStringList irregularityTypeNames() const;
	QList<int> defaultIrregularityTypeClasses() const;
	QString irregularityTypeName(int type) const;
	int irregularityTypeNumber(int tenseNum, int timeNum) const;
	int numberOfIrregularityTypes() const;
	int numberOfTenses() const;
	int numberOfForms(int tenseNum) const;
	QStringList similarVerbs() const;

signals:
	void showError(const QString &message);

private:
	bool findTranslator(QTranslator *translator, const QString &transName, const QString &transDirPath) const;
	QTranslator *createTranslator(const QString &transBaseName, const QStringList &translationsDirList) const;
	QList<QTranslator*> createPluginTranslators() const;

	QList<Plugin*> m_pluginsList;
	QStringList m_pluginFileNamesList;
	Plugin *m_currentPlugin;

	QList<QTranslator*> m_pluginTranslatorsList;

	Verb *m_verb;
	bool m_showPronouns;
};

} // end namespace

#endif
