/***************************************************************************
 *   Copyright (C) 2007-2009 by Glad Deschrijver                           *
 *   glad.deschrijver@gmail.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#ifndef QONJUGATOR_TENSE_H
#define QONJUGATOR_TENSE_H

namespace Qonjugator
{

/*!
 * This class contains a single tense and its description.
 */

struct Tense
{
	/*!
	 * This variable holds the name of the mood of the tense.
	 * For example in French possible moods are "indicatif",
	 * "conditionnel", "subjonctif",
	 * \htmlonly "imp&eacute;ratif", \endhtmlonly
	 * \latexonly "imp\'eratif", \endlatexonly
	 * ...
	 */
	QString mood;

	/*!
	 * This variable holds the name of the tense.
	 * For example in French possible tense names are
	 * \htmlonly "pr&eacute;sent", "imparfait", "pass&eacute; compos&eacute;", \endhtmlonly
	 * \latexonly "pr\'esent", "imparfait", "pass\'e compos\'e", \endlatexonly
	 * ...
	 */
	QString name;

	/*!
	 * The list containing the different forms of the tense.
	 * For example, in French, the forms of the
	 * \htmlonly "indicatif pr&eacute;sent" \endhtmlonly
	 * \latexonly "indicatif pr\'esent" \endlatexonly
	 * of the verb "parler" are "parle", "parles", "parle",
	 * "parlons", "parlez", "parlent".  The forms should be put
	 * in the list in the same order as you want them to appear
	 * on screen.
	 */
	QList<QString> forms;

	/*!
	 * The list containing the irregularity types of each form
	 * of the tense.  Each entry in this list describes the
	 * irregularity type of the corresponding entry of Tense#tense.
	 * The value 0 stands for a regular form, for any other type of
	 * irregularity any integer can be chosen by the plugin developer.
	 */
	QList<int> irregularityTypes;
};

/*!
 * This class contains the conjugation of a single verb.
 */

class Verb
{
public:
	~Verb()
	{
		while (!tenses.isEmpty())
			delete tenses.takeFirst();
	}

	/*!
	 * Contains the infinitive of the verb.
	 */
	QString infinitive;

	/*!
	 * Contains the base infinitive of the reciprocal verb (i.e.
	 * without the reciprocal pronoun(s)).  For example in French
	 * the base infinitive of "se promener" is "promener".  If the
	 * verb is not reciprocal, then this variable has the same
	 * value as Verb#infinitive.
	 */
	QString infinitiveBase;

	/*!
	 * This is a list of the different tenses.  The tenses must be
	 * ordered in the same order as you wish them to appear on screen.
	 * \sa See Tense for more information.
	 */
	QList<Tense*> tenses;
};

} // end namespace

#endif
