# Find QonjugatorLib
# Once done this will define
#
#  QONJUGATOR_FOUND				- system has Qonjugator Library
#  QONJUGATOR_INCLUDES			- the Qonjugator include directory
#  QONJUGATOR_LIBRARIES			- link these to use Qonjugator
#  QONJUGATOR_PLUGINSDIR		- Qonjugator plugins installation directory
#  QONJUGATOR_TRANSLATIONSDIR	- Qonjugator translations installation directory
#  QONJUGATOR_VERSION			- the version of the Qonjugator Library

macro(_qonjugator_find_version)
	set(QONJUGATOR_VERSION "0.15")
	message(STATUS "QonjugatorLib version: ${QONJUGATOR_VERSION}")
endmacro(_qonjugator_find_version)

### Search Qt4 libraries and headers and set some useful definitions
find_package(Qt4 REQUIRED)
include(${QT_USE_FILE})

### Search QonjugatorLib libraries and headers and set some useful definitions
if (QONJUGATORLIB_FOUND)
	# Already found, nothing more to do except figuring out the version
	_qonjugator_find_version()
else (QONJUGATORLIB_FOUND)
	if (QONJUGATORLIB_INCLUDE_DIR AND QONJUGATORLIB_LIBRARY)
		set(QONJUGATORLIB_FIND_QUIETLY TRUE)
	endif (QONJUGATORLIB_INCLUDE_DIR AND QONJUGATORLIB_LIBRARY)

	# Find the location of the library
	find_library(QONJUGATORLIB_LIBRARY
	             NAMES qonjugatorcore
	             PATHS ${QT_LIBRARY_DIR} NO_SYSTEM_ENVIRONMENT_PATH NO_CMAKE_SYSTEM_PATH)
	find_library(QONJUGATORLIB_LIBRARY
	             NAMES qonjugatorcore)

	# Find the location of the headers
	find_path(QONJUGATORLIB_INCLUDE_DIR
	          NAMES qonjugator/qonjugatorplugin.h
	          PATHS ${QT_INCLUDE_DIR} NO_SYSTEM_ENVIRONMENT_PATH NO_CMAKE_SYSTEM_PATH)
	find_path(QONJUGATORLIB_INCLUDE_DIR
	          NAMES qonjugator/qonjugatorplugin.h)

	# Set some useful variables
	if (QONJUGATORLIB_INCLUDE_DIR AND QONJUGATORLIB_LIBRARY)
		set(QONJUGATOR_LIBRARIES ${QONJUGATORLIB_LIBRARY})
		set(QONJUGATOR_INCLUDES ${QONJUGATORLIB_INCLUDE_DIR}/qonjugator)
		set(QONJUGATOR_PLUGINSDIR ${QONJUGATORLIB_INCLUDE_DIR}/../lib/qonjugatorplugins)
		set(QONJUGATOR_TRANSLATIONSDIR ${QONJUGATORLIB_INCLUDE_DIR}/../share/qonjugator)
		set(QONJUGATORLIB_FOUND TRUE)
		_qonjugator_find_version()
	else (QONJUGATORLIB_INCLUDE_DIR AND QONJUGATORLIB_LIBRARY)
		set(QONJUGATORLIB_FOUND FALSE)
	endif (QONJUGATORLIB_INCLUDE_DIR AND QONJUGATORLIB_LIBRARY)

	# Tell the user what we have achieved
	if (QONJUGATORLIB_FOUND)
		if (NOT QONJUGATORLIB_FIND_QUIETLY)
			message(STATUS "Found QonjugatorLib: ${QONJUGATORLIB_LIBRARY}")
			message(STATUS "Found QonjugatorLib includes: ${QONJUGATOR_INCLUDES}")
		endif (NOT QONJUGATORLIB_FIND_QUIETLY)
	else (QONJUGATORLIB_FOUND)
		if (QonjugatorLib_FIND_REQUIRED)
			if (NOT QONJUGATORLIB_INCLUDE_DIR)
				message(STATUS "QonjugatorLib includes NOT found!")
			endif (NOT QONJUGATORLIB_INCLUDE_DIR)
			if (NOT QONJUGATORLIB_LIBRARY)
				message(STATUS "QonjugatorLib library NOT found!")
			endif (NOT QONJUGATORLIB_LIBRARY)
			message(FATAL_ERROR "QonjugatorLib library or includes NOT found!")
		else (QonjugatorLib_FIND_REQUIRED)
			message(STATUS "Unable to find QonjugatorLib")
		endif (QonjugatorLib_FIND_REQUIRED)
	endif (QONJUGATORLIB_FOUND)

	mark_as_advanced(QONJUGATOR_INCLUDE_DIR QONJUGATOR_LIBRARY QONJUGATOR_INCLUDES)
endif (QONJUGATORLIB_FOUND)

### Uninstall
if (NOT qonjugator_uninstall_rule_created)
	set(qonjugator_uninstall_rule_created TRUE)
	configure_file("${CMAKE_CURRENT_SOURCE_DIR}/../cmake_uninstall.cmake.in"
	               "${CMAKE_CURRENT_BINARY_DIR}/cmake_uninstall.cmake"
	               IMMEDIATE @ONLY)
	add_custom_target(uninstall
	                  "${CMAKE_COMMAND}" -P "${CMAKE_CURRENT_BINARY_DIR}/cmake_uninstall.cmake")
endif(NOT qonjugator_uninstall_rule_created)
